package Catalyst::Authentication::Store::DBI;
use strict;
use warnings;

die 'This is a search.cpan notice';

package Catalyst::Authentication::Store::DBI::ButMaintained::FoolCPAN;

sub die { die @_ };

1;

=head1 DEPRECATION NOTICE

=head2 AFAIK, L<Catalyst::Authentication::Store::DBI> IS NO LONGER MAINTAINED

=head2 PLEASE SEE L<Catalyst::Authentication::Store::DBI::ButMaintained>

=head2 THANKS, EVAN CARROLL
